@@ -185,7 +185,7 @@ impl<T: Renderer> Ui<T> {
     }
 
     //
-    // stack getters
+    // Stack getters (and setters)
     //
 
     /// Returns the position of the topmost group, in absolute (screen) coordinates.
@@ -193,6 +193,11 @@ impl<T: Renderer> Ui<T> {
         self.top().rect.position
     }
 
+    /// Sets the absolute position of the topmost group.
+    pub fn set_position(&mut self, new_position: Point) {
+        self.top_mut().rect.position = new_position;
+    }
+
     /// Returns the size of the topmost group.
     pub fn size(&self) -> Vector {
         self.top().rect.size
@@ -208,6 +213,12 @@ impl<T: Renderer> Ui<T> {
         self.top().rect.height()
     }
 
+    /// Returns the current group's rectangle. The rectangle's position is expressed in
+    /// absolute coordinates.
+    pub fn rect(&self) -> Rect {
+        self.top().rect
+    }
+
     /// Returns the "remaining size" of the current group. This is measured by subtracting the group's cursor from
     /// its size, effectively giving you the size that remains in the group. In reversed layouts, the cursor is added
     /// instead, as it goes into the negative. On the freeform layout, this always returns (0, 0).
